@@ -14,6 +14,12 @@ from typing import (
     Any,
 )
 
+TASK_NAME_PREFIX = "task_queue_"
+
+
+class FailedValidation(Exception):
+    pass
+
 
 def validate_message(message: dict[str, Any]) -> bool:
     with suppress(ValidationError):
